@@ -20,7 +20,7 @@ class capitalDivisionAsker : public boxAsker
 		capitalDivisionAsker(QWidget *parent, KGmap *m, QWidget *w, uint count);
 
 	protected:
-		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer) override;
+		bool nextBoxAskerQuestionHook(const division *div, int i, bool isAnswer) override;
 		void setAnswerHook(int userSays) override;
 		QString getQuestionHook() const override;
 		division::askMode askMode() const override { return division::eCapital; }
